@@ -7,13 +7,16 @@ app = typer.Typer()
 def my_cli_app(
     git_url: str = typer.Option(..., help="The Git URL"),
     git_branch: str = typer.Option(..., help="The Git branch"),
-    app_name: str = typer.Option(..., help="The application name")
+    app_name: str = typer.Option(..., help="The application name"),
+    explain: bool = typer.Option(False, "--explain", "-e", help="This command clones your repository, processes the files against Watsonx, and provides output with code summaries, comments, and unit test cases.")
 ):
     """
     A CLI app that calls an API with given Git details and prints the CLI command.
     """
-    # Call the API
-    print("git url", git_url)
+    if explain:
+        typer.echo("This command calls an API with the provided Git details and prints the CLI command.")
+        return
+
     headers = {
         "accept": "application/json",
         "Content-Type": "application/json"
@@ -26,21 +29,15 @@ def my_cli_app(
         }
     }
     url = "https://code-explorer-pre-prod.dal2a.ciocloud.nonprod.intranet.ibm.com/api/github"
-    #print("url", url)
     response = requests.post(url, json=body, headers=headers)
-    #print("response", response)
     if response.status_code == 201:
-        typer.echo("Request Submitted!")
-        #typer.echo("Response:")
-        #typer.echo(response.json())
+        typer.echo("Your request has been submitted. Please check your repository later. You will receive a new pull request from WCA Code Explorer.")
     else:
         typer.echo(f"Request failed. Please contact DX-WX-4code Team.")
-        #typer.echo("Response:")
-        #typer.echo(response.text)
 
     # Print the command
     command = f"my_cli_app --git-url {git_url} --git-branch {git_branch} --app-name {app_name}"
-    #print(command)
+    #typer.echo(f"Command: {command}")
 
 if __name__ == "__main__":
     app()
